@@ -1,10 +1,13 @@
 from typing import Type
 from flask_sqlalchemy import SQLAlchemy
+from sqlalchemy.sql.sqltypes import TypeEngine
 from .model import Model
 
 
-def Column(primary_key: bool):
-    pass
+def Column(
+    sqltype: TypeEngine,
+    primary_key: bool = False,
+): pass
 
 
 def create_all(bind='__all__', app=None):
